.. include:: ../README.rst

.. toctree::
   :caption: Getting Started
   :maxdepth: 2
   :hidden:

   installation
   configuration
   using_protocols
   writing_protocols
   sharing_protocols
   planning_protocols

.. toctree::
   :caption: Config Reference

   config/search
   config/printer

.. toctree::
   :caption: API Reference

   api/load
   api/protocol
   api/master_mix
   api/reaction
   api/reagent
   api/solvent
   api/quantity
   api/tabulate
   api/config
   api/errors

.. toctree::
   :caption: Development

   contributing
